==> sfa-rpc-0.0.35-sources.jar: com/biz/sfa/vo/req/media/AllMarketingSearchListRpcReqVo.java <==
package com.biz.sfa.vo.req.media;

import com.biz.sfa.enums.ActivityStyleEnum;
import com.biz.sfa.enums.CostTypeEnum;
import com.biz.sfa.enums.MediaCategoriesEnum;
import com.biz.sfa.enums.SubdivisionEnum;

import java.io.Serializable;

/**
 * Created by Administrator on 2017/7/17.
 */
public class AllMarketingSearchListRpcReqVo implements Serializable{
    private static final long serialVersionUID = 4605147633774453160L;
    /**
     * 媒体大类
     */
    private MediaCategoriesEnum mediaCategories;

    /**
     * 费用类型
     */
    private CostTypeEnum costType;

    /**
     * 小类
     */
    private SubdivisionEnum subdivision;

    /**
     * 活动形式
     */
    private ActivityStyleEnum activityStyle;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 媒体库编码
     */
    private String mediaCode;

    /**
     * 搜索类型 (1 主数据 2 rpc)
     */
    private Integer searchType;

    public MediaCategoriesEnum getMediaCategories() {
        return mediaCategories;
    }

    public void setMediaCategories(MediaCategoriesEnum mediaCategories) {
        this.mediaCategories = mediaCategories;
    }

    public CostTypeEnum getCostType() {
        return costType;
    }

    public void setCostType(CostTypeEnum costType) {
        this.costType = costType;
    }

    public SubdivisionEnum getSubdivision() {
        return subdivision;
    }

    public void setSubdivision(SubdivisionEnum subdivision) {
        this.subdivision = subdivision;
    }

    public ActivityStyleEnum getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleEnum activityStyle) {
        this.activityStyle = activityStyle;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public String getMediaCode() {
        return mediaCode;
    }

    public void setMediaCode(String mediaCode) {
        this.mediaCode = mediaCode;
    }

    public Integer getSearchType() {
        return searchType;
    }

    public void setSearchType(Integer searchType) {
        this.searchType = searchType;
    }
}

==> sfa-rpc-0.0.60-sources.jar: com/biz/sfa/vo/req/media/AllMarketingSearchListRpcReqVo.java <==
package com.biz.sfa.vo.req.media;

import java.io.Serializable;

import com.biz.sfa.enums.ActivityStyleEnum;
import com.biz.sfa.enums.CostTypeEnum;
import com.biz.sfa.enums.MediaCategoriesEnum;
import com.biz.sfa.enums.SubdivisionEnum;

/**
 * Created by Administrator on 2017/7/17.
 */
public class AllMarketingSearchListRpcReqVo implements Serializable{

    private static final long serialVersionUID = 4605147633774453160L;

    /**
     * 媒体大类
     */
    private MediaCategoriesEnum mediaCategories;

    /**
     * 费用类型
     */
    private CostTypeEnum costType;

    /**
     * 小类
     */
    private SubdivisionEnum subdivision;

    /**
     * 活动形式
     */
    private ActivityStyleEnum activityStyle;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 媒体库编码
     */
    private String mediaCode;

    /**
     * 搜索类型 (1 主数据 2 rpc)
     */
    private Integer searchType;

    /**
     * 岗位编码
     */
    private String jobCode;

    private String activityStyleName;
    
    public String getActivityStyleName() {
		return activityStyleName;
	}

	public void setActivityStyleName(String activityStyleName) {
		this.activityStyleName = activityStyleName;
	}

	public MediaCategoriesEnum getMediaCategories() {
        return mediaCategories;
    }

    public void setMediaCategories(MediaCategoriesEnum mediaCategories) {
        this.mediaCategories = mediaCategories;
    }

    public CostTypeEnum getCostType() {
        return costType;
    }

    public void setCostType(CostTypeEnum costType) {
        this.costType = costType;
    }

    public SubdivisionEnum getSubdivision() {
        return subdivision;
    }

    public void setSubdivision(SubdivisionEnum subdivision) {
        this.subdivision = subdivision;
    }

    public ActivityStyleEnum getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleEnum activityStyle) {
        this.activityStyle = activityStyle;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    public String getMediaCode() {
        return mediaCode;
    }

    public void setMediaCode(String mediaCode) {
        this.mediaCode = mediaCode;
    }

    public Integer getSearchType() {
        return searchType;
    }

    public void setSearchType(Integer searchType) {
        this.searchType = searchType;
    }

    public String getJobCode() {
        return jobCode;
    }

    public void setJobCode(String jobCode) {
        this.jobCode = jobCode;
    }
}
